@@ -1,7 +1,7 @@
 from abc import ABCMeta
 
 #: N804:7:13
-class Foo(object):
+class Foo:
     @classmethod
     def mmm(cls, ads):
         pass
@@ -17,17 +17,17 @@ class Foo(object):
     def __init_subclass(self, ads):
         pass
 #: Okay(--ignore-names=klass)
-class SpecialConventionCase(object):
+class SpecialConventionCase:
     @classmethod
     def prepare_meta(klass, root):
         pass
 #: Okay(--ignore-names=_*)
-class SpecialConventionCase(object):
+class SpecialConventionCase:
     @classmethod
     def prepare_meta(_class, root):
         pass
 #: N804:3:14(--classmethod-decorators=clazzy,cool)
-class NewClassIsRequired(object):
+class NewClassIsRequired:
     @cool
     def test(self, sy):
         pass
@@ -43,7 +43,44 @@ class MetaMethod(ABCMeta):
     def test(cls):
         pass
 #: Okay
-class NotMeta(object):
+class NotMeta:
+    otherclass = Foo
+class AttributeParent(NotMeta.otherclass):
+    pass
+class CallParent(type('_tmp', (), {})):
+    pass
+
+#: N804:7:19
+class Foo:
+    @classmethod
+    async def mmm(cls, ads):
+        pass
+
+    @classmethod
+    async def bad(self, ads):
+        pass
+
+    @calling()
+    async def test(self, ads):
+        pass
+
+    async def __init_subclass(self, ads):
+        pass
+#: N804:3:20(--classmethod-decorators=clazzy,cool)
+class NewClassIsRequired:
+    @cool
+    async def test(self, sy):
+        pass
+#: N804
+class Meta(type):
+    async def __new__(self, name, bases, attrs):
+        pass
+#: Okay
+class MetaMethod(type):
+    async def test(cls):
+        pass
+#: Okay
+class NotMeta:
     otherclass = Foo
 class AttributeParent(NotMeta.otherclass):
     pass
